module.exports = function (grunt) {
  'use strict';

  // Load all grunt tasks matching the `grunt-*` pattern.
  require('load-grunt-tasks')(grunt);

  var config = {
    base:    './',
    scss:    'sass',
    css:     'css',
    img:     'images',
    tests:   'test',
    sassdoc: 'sass-doc'
  };

  var pkg = grunt.file.readJSON('package.json');

  grunt.initConfig({
    pkg: pkg,

    conf: config,

    watch: {
      dev:  {
        files:   ['<%= conf.scss %>/**/*.scss'],
        tasks:   ['shell:compass'],
        options: {
          livereload: true
        }
      },
      test: {
        files: ['<%= conf.scss %>/**/*.scss'],
        tasks: ['shell:compass']
      }
    },

    shell: {
      theme:   {
        command: 'drush cache-clear theme-registry'
      },
      compass: {
        command: 'bundle exec compass compile'
      },
      guard:   {
        command: 'bundle exec guard'
      }
    },

    scsslint: {
      allFiles: [
        '<%= conf.scss %>/**/*.scss'
      ],
      options:  {
        bundleExec:     true,
        config:         '.scss-lint.yml',
        reporterOutput: 'scss-lint-report.xml',
        colorizeOutput: true
      }
    },

    jshint: {
      all: ['Gruntfile.js', 'js/*.js', 'js/custom/*.js']
    },

    sassdoc: {
      default: {
        src:     '<%= conf.scss %>',
        dest:    '<%= conf.sassdoc %>',
        options: {
          verbose:  true,
          display:  {
            access:    ['public', 'private'],
            alias:     false,
            watermark: true
          },
          groups:   {
            'undefined': 'General',
            'button':    'Buttons',
            'color':     'Colors',
            'typo':      'Typographie'
          },
          package:  pkg,
          theme:    'default',
          basePath: '../<%= conf.scss %>'
        }
      }
    },

    casper: {
      options: {
        test: true
      },
      login: {
        src: ['<%= conf.test %>/login.js']
      }
    }
  });

  // compiling current state and generate docs
  grunt.registerTask('compile', [
    'shell:compass',
    'sassdoc'
  ]);

  // linting and testing stuff
  grunt.registerTask('test', [
    'scsslint',
    'jshint',
    'casper:login'
  ]);

  grunt.registerTask('dev', [
    'watch:dev'
  ]);

  // for local dev with vhost running using guard-setup
  grunt.registerTask('guard', [
    'shell:guard'
  ]);

  // scss-lint shortcut
  grunt.registerTask('cl', [
    'scsslint'
  ]);
};
